from fabriclassed import BaseFabric, initialize
from fabric import api as fab

class Fabric(BaseFabric):
    name = 'website'
    local_file = '/local/path/to/my_website'
    remote_file = '/remote/path/to/my_website'

    def task(self):
        '''my website task'''
        fab.local('echo "Hello world"')

__all__ = initialize(Fabric(), __name__)


from utils import add_class_methods_as_module_level_functions_for_fabric as initialize
from base import BaseFabric
from django import DjangoFabric
from virtualenv import VirtualenvFabric

VERSION = (0, 3, 2)
__version__ = '.'.join(map(str, VERSION))
__all__ = ['FabricBase', 'DjangoFabric', 'VirtualenvFabric', 'initialize']